\documentclass[12pt,a4paper,twoside]{article}
\usepackage[colorlinks=true]{hyperref}
\usepackage[utf8]{inputenc}
\usepackage[czech]{babel}
\usepackage{graphicx}
\usepackage{fancyhdr}
\usepackage{fullpage}
\usepackage[top=5cm, bottom=10cm, left=2.5cm, right=2.5cm]{geometry}
\textwidth 16cm \textheight 20cm
\topmargin 0cm 
\oddsidemargin 0cm
\pagestyle{fancy}
\addtolength{\headsep}{30 pt}
\addtolength{\footskip}{50 pt}

%\fancyfoot{}
%\fancyfoot{\hspace*{5cm}}
%\fancyfoot[L]{\hspace{0.5cm}  pomiceva}
%\fancyfoot[R] {\thepage}


\begin{document}
\title{Technický popis Automatického vypouštěče meteorologických balónů}
\author{Eva Pomíchalová}
\maketitle


\thispagestyle{fancy}
\newpage
\begin{abstract}
\input{abstrakt.txt}

\end{abstract}
\newpage

%%\begin{figure} [htbp]
%%\begin{center}
%%\includegraphics [width=80mm] {SDRX01B_Top_Big.JPG} 
%%\end{center}
%%\end{figure}

\tableofcontents
\newpage

\section{Automatický vypouštěč meteobalónů}

Celý systém by měl být robotizovaným doplňkem sítě
\href{/doku.php?id=cs:rmds}{radiových detektorů meteorů} [\ref{fig:blokcelasit}], případně pak i
její vizuální varianty (video pozorování
\textsuperscript{\href{\#fn\_\_1}{1)}} a bolidové kamery).

Účelem zařízení je zpřesnění odhadu trajektorie temné dráhy meteoritu v
atmosféře zavedením korekcí na proudění vzduchových mas během letu. A
tím v důsledku zmenšit plochu dopadové elipsy.

Údaje o proudech v atmosféře budou získány balónovou sondou vypuštěnou
bezprostředně po detekci průletu bolidu atmosférou. Místo vypuštění
balónové sondy by mělo být zvoleno automaticky na základě odhadu dráhy
meteoru a známých souřadnic balónových sil v síti.

Důležitou součástí systému je plně robotizovaná vypouštěcí stanice
(balónové silo), která umožní vypuštění sondy ze známých souřadnic bez
zásahu lidské obsluhy. Vedlejším produktem takového vývoje bude zařízení
schopné v budoucnu automatizovat i vypouštění klasických
meteorologických
\href{http://en.wikipedia.org/wiki/Radiosonde}{radiosond}.

\begin{figure}
  \centering
  \includegraphics[width=15cm, height=9cm]{img/SchemaCeleSite.png}
  \caption{Schéma celé sítě}
  \label{fig:blokcelasit}
\end{figure}

\subsection{Pozemní vypouštěcí box}

Pozemní stanici balónové sítě bude tvořit kompaktní krabice obsahující
techniku potřebnou k vypuštění balónové sondy. Zařízení musí být
konstruováno tak, aby bylo schopné vydržet řádově několik roků v
pohotovostním režimu, a čekat na příkaz k vypouštění sondy.

\subsubsection{Technické požadavky}

Většinu řídící elektroniky lze složit z modulů
\href{http://www.mlab.cz/}{stavebnice MLAB}

\paragraph{Komunikace se sítí stanic}

\begin{itemize}
\item
  Ethernet - modulem \href{/doku.php?id=cs:eth}{ETH01A}
\item
  RS232 - \href{/doku.php?id=cs:rs232single}{RS232SINGLE01A}
\item
  GSM (pro odlehlé oblasti)
\end{itemize}
Zároveň bude potřeba také vybavení pro příjem telemetrie z již
vypuštěných radiosond \textsuperscript{\href{\#fn\_\_2}{2)}} z jiných
stanic.

Tyto požadavky splňuje modul
\href{/doku.php?id=cs:stm32f10xrxt}{STM32F10xRxT01A}

\paragraph{Napájení systému}

\begin{itemize}
\item
  lokální (stand-alone) - Fotovoltaický panel
\item
  Síťové napájení (síťový adaptér + UPS)
\end{itemize}
\paragraph{Diagnostika poruch}

\begin{itemize}
\item
  Kontrola úspěšného startu (měření vztlaku balónu)
\item
  Měření teplot, tlaku plynové náplně, průtoku média do balónu.
\item
  Vlhkost uvnitř krabice (průsak a ztráta vodotěsnosti proražením víka a
  podobně)
\end{itemize}
\paragraph{Meteorologická data}

\begin{itemize}
\item
  Základní meteorologická čidla (teplota, tlak, rychlost větru) - k
  určení možnosti startu. \href{/doku.php?id=cs:aws}{AWS01B}
\item
  GPS (pozice stanice a přesný čas)  log reportu o startu.
  \href{/doku.php?id=cs:gps}{GPS01A}
\end{itemize}
\paragraph{Mechanická konstrukce}

\begin{itemize}
\item
  Svařovaná plastová bedna s odstranitelným víkem. Dostatečně těsná, aby
  nebyla zajímavá pro hlodavce a další havěť.
\item
  Konstrukce navržená tak, aby umožnila vypouštění i současných
  profesionálních balónových sond.
\item
  Aktivace mechanických prvků přepálením vlákna
\item
  uzavření balónu zatavením hrdla
\end{itemize}
\subparagraph{Akční členy}

Většina akčních členů by měla být konstruována s důrazem na maximální
spolehlivost. Akční členy proto pravděpodobně budou pružiny s
přepalovacími PE pojistkami (silonové vlákno, nebo stuha
přepalovaná výkonovým rezistorem) ke spínáni proudu do rezistorů může
být využit modul \href{/doku.php?id=cs:nfet4x}{NFET4X01B}

\hyperdef{}{firmware}{\paragraph{Firmware}\label{firmware}}

\begin{itemize}
\item
  Pozemní stanice by měla mít možnost odmítnout vypuštění na základě
  zadané konfigurace jejího majitele.
\end{itemize}
Pro zajištění běhu nezávislých procesů by bylo možná vhodné využít
\href{http://www.chibios.org/dokuwiki/doku.php}{ChibiOS/RT}

\begin{figure}
  \centering
  \includegraphics[width=10cm, height=8cm]{img/blokoveschema1.png}
  \caption{Blokové schéma pozemního vypouštěcího boxu}
\label{fig:blokpozem}
\end{figure}


\subsection{Balónová sonda}

Neletový prototyp sondy bude vyvinut za použití modulů stavebnice
\href{http://www.mlab.cz/Server/GenIndex/GenIndex.php?lang=cs\&path=/Modules}{MLAB}

\href{/doku.php?id=cs:atmegatq32}{ATmegaTQ3201A},
\href{/doku.php?id=cs:sdcard}{SDcard01B},
\href{/doku.php?id=cs:gps}{GPS01A}

\subsubsection{Technické parametry}

GPS na sondě by měla být udržovaná ve stavu FIX, aby pak nedocházelo ke
zpoždění v důsledku čekání na fix.

\paragraph{Komunikace (Telemetrické údaje)}

\begin{itemize}
\item
  Primárním cílem je měření rychlosti a směru větru ve známých bodech.
\item
  GPS údaje 10Hz, textový výstup
  \href{http://en.wikipedia.org/wiki/NMEA\_0183}{NMEA}
\item
  další veličiny jako teploty, tlaky atd. jsou volitelné.
\item
  Radio maják a akustický maják?
\item
  Radiový přenos telemetrie v pásmu 27-450 MHz: možnost bezlicenčních
  pásem (SVN: VO-R-16, VO-R-10)
\item
  Radiomoduly: \href{http://www.artbrno.cz}{http://www.artbrno.cz},
  \href{http://www.anaren.com}{http://www.anaren.com}
\end{itemize}
GPS je potřeba vybrat tak, aby fungovala i ve větších výškách.
\textsuperscript{\href{\#fn\_\_3}{3)}}

\paragraph{Napájení sondy během letu}

\begin{itemize}
\item
  \href{http://en.wikipedia.org/wiki/Lithium\_battery}{Lithiový článek}
  (negeneruje teplo, minimální provozní teplota je -60 C)
\item
  Hořčíková baterie (generuje teplo pro temperování elektroniky)
\item
  \href{http://en.wikipedia.org/wiki/Silver-oxide\_battery}{Stříbro-oxidový
  článek} Vydrží nižší provozní teploty a je ekologicky nezávadný.
\item
  Ideální by bylo použití
  \href{https://www.youtube.com/watch?feature=player\_embedded\&v=OtM6XJlynkk}{superkapacitorů}
\end{itemize}
Řešením problému s nízkou teplotou ve vyšších výškách by mohlo být
předehřátí sondy při startu.

\hyperdef{}{konstrukce}{\paragraph{Konstrukce}\label{konstrukce}}

\begin{itemize}
\item
  Balón - \href{http://cs.wikipedia.org/wiki/Polyethylen}{PE} pytel
  (kvůli životnosti v zabaleném stavu - guma s časem degraduje)
  \textsuperscript{\href{\#fn\_\_4}{4)}}
\item
  Možnost dálkového odpojení balónu od sondy (ukončení stoupání)
\item
  Prototyp plněný \href{http://cs.wikipedia.org/wiki/Helium}{heliem},
  i ekologičtější. A vodík navíc lze vyrábět chemicky přímo během
  vypuštění sondy).
\item
  Splnění požadavků na bezpečnost provozu (letovou, majetkovou a
  personální)
\end{itemize}

\begin{figure}
 \centering
 \includegraphics[width=10cm, height=8cm]{img/blokoveschema2.png}
 \caption{Blokové schéma balónové sondy}
\label{fig:blokpozem}
\end{figure}

\subsection{Řídící systém sítě}

\subsubsection{Zpracování dostupných dat}

\begin{itemize}
\item
  Odhad vektoru meteoru v atmosféře
\item
  Záznam dostupných meteorologických dat pro pozdější rekonstrukci
  (družicové snímky, aktuálně měřené hodnoty ČHMÚ, radarové snímky)
\item
  sběr dat z jednotlivých stanic
\item
  výpočet vektoru a výškových profilů větru
\end{itemize}
\subsubsection{Rozhodovací proces}

Použití nějakého skriptovacího jazyka pro popis procesu
\href{http://www.ros.org/wiki/}{ROS}?

\begin{itemize}
\item
  Přidělení příkazu ke startu jednotlivým stanicím.
\item
  Přeplánování startu v důsledku neúspěšného vypuštění nebo zamítnutí
  stanicí.
\item
  Kontrola potenciálního narušení vzdušného prostoru a zakázaných zón.
\end{itemize}
\subsubsection{Správa systému}

\begin{itemize}
\item
  registrace jednotlivých stanic a správa uživatelů v kooperaci s
  projektem \href{http://www.astrozor.cz/}{Astrozor}
\end{itemize}

\newpage

\begin{thebibliography}{99}
\bibitem{cement}{například síť CEMeNt} 
\url{http://cement.fireball.sk/}
\bibitem{radiosondy}{radiosondy} 
\url{http://www.radiosonde.eu/}, \url{http://www.radiosonda.sk/}
\bibitem{cocom}{směrnice CoCom} 
\url{http://en.wikipedia.org/wiki/CoCom\#Legacyi}
\bibitem{moguli}{projekt Mogul} 
\url{http://cs.wikipedia.org/wiki/Projekt\_Moguli}



\end{thebibliography}
\end{document}